@@ -1,8 +1,11 @@
+import json
 import logging
 import os
 from logging.config import dictConfig
 from logging.handlers import RotatingFileHandler
 
+from _jsonnet import evaluate_snippet
+
 from handystuff.loaders import load_jsonnet
 import tqdm
 
@@ -17,9 +20,11 @@ def setup_logging(path=None):
 
     """
     from pkg_resources import resource_string
-    path = path or resource_string(__name__, "resources/logging.jsonnet")
-    cfg = load_jsonnet(path)
-
+    if path:
+        with open(path, 'r') as f:
+            string = f.read()
+    string = resource_string(__name__, "resources/logging.jsonnet").decode('utf-8')
+    cfg = json.loads(evaluate_snippet(path or 'default', string))
     # noinspection PyUnresolvedReferences
     dictConfig(cfg)
 
